delete_card_response = """{
  "object": "card",
  "id": "card_test_5s1jzsw6iy9nw4gzmx3",
  "livemode": false,
  "location": "/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzsw6iy9nw4gzmx3",
  "deleted": true,
  "street1": null,
  "street2": null,
  "city": "Bangkok",
  "state": null,
  "phone_number": null,
  "postal_code": "10320",
  "country": "us",
  "financing": "credit",
  "bank": "JPMORGAN CHASE BANK N.A.",
  "brand": "Visa",
  "fingerprint": "7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=",
  "first_digits": null,
  "last_digits": "4242",
  "name": "JOHN DOE",
  "expiration_month": null,
  "expiration_year": null,
  "security_code_check": true,
  "tokenization_method": null,
  "created_at": "2022-06-05T09:39:29Z"
}"""
